===========
violin-plot
===========

The :class:`CGATReportPlugins.Plotter.ViolinPlot` displays
:term:`numerical arrays` as boxplots.

.. report:: Trackers.SingleColumnDataExample
   :render: violin-plot
   :layout: row
   :width: 200

   A violin-plot.

Options
-------

:class:`CGATReportPlugins.Plotter.ViolinPlot` has no additional
options apart from :ref:`common plot options`. 

